/******************************************************************************
 * $Id: gdal_view.cpp,v 1.1 1999/01/11 15:27:23 warmerda Exp $
 *
 * Name:     gdal_view.cpp
 * Project:  GDAL Qt Viewer
 * Purpose:  Mainline
 * Author:   Frank Warmerdam, warmerda@home.com
 *
 ******************************************************************************
 * Copyright (c) 1999, Frank Warmerdam
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *****************************************************************************
 *
 * $Log: gdal_view.cpp,v $
 * Revision 1.1  1999/01/11 15:27:23  warmerda
 * New
 *
 */

#include "gview.h"


int main( int argc, char **argv )
{
    GDALDatasetH	hDS;
    GVRaster		*poRaster;
    GVViewWindow	*poView;
    QApplication 	oGViewApplication( argc, argv );

    if( argc < 2 )
    {
        printf( "Usage: gview filename\n" );
        exit( 1 );
    }

/* -------------------------------------------------------------------- */
/*      Open the dataset.                                               */
/* -------------------------------------------------------------------- */
    GDALAllRegister();
    hDS = GDALOpen( argv[1], GA_ReadOnly );
    if( hDS == NULL )
    {
        printf( "GDALOpen(%s) failed.\n", argv[1] );
        exit ( 1 );
    }

/* -------------------------------------------------------------------- */
/*      Create a GVRaster from the source file.                         */
/* -------------------------------------------------------------------- */
    if( GDALGetRasterCount(hDS) < 3 )
        poRaster = new GVRaster( hDS, 1, 1, 1 );
    else
        poRaster = new GVRaster( hDS, 1, 2, 3 );
    
/* -------------------------------------------------------------------- */
/*      Create a GVViewWindow, and configure.                           */
/* -------------------------------------------------------------------- */
    poView = new GVViewWindow( NULL, "View1" );
    oGViewApplication.setMainWidget( poView );

    poView->resize( 512, 512 );
    poView->SetGVRaster( poRaster );

    poView->show();
    
    return oGViewApplication.exec();
}

